import axios from "axios";
import { OrderStateColumns } from "src/db";
import { AddNewOrderType } from "src/schema";

export async function loadOrder() {
  return (await axios.get<OrderStateColumns[]>("/api/order")).data;
}

export async function loadOrderById(id: string) {
  return (await axios.get<OrderStateColumns>(`/api/order/${encodeURIComponent(id)}`)).data;
}

export async function addNewOrder(order: AddNewOrderType) {
  return await axios.post("/api/order", order);
}

export async function cancelOrder(id: string) {
  return await axios.delete(`/api/order/${encodeURIComponent(id)}`);
}

export async function completeOrder(id: string) {
  return await axios.post(`/api/order/${encodeURIComponent(id)}/complete`);
}

export async function cancelCompleteOrder(id: string) {
  return await axios.post(`/api/order/${encodeURIComponent(id)}/cancel-complete`);
}

export async function clearOrder() {
  return await axios.delete("/api/order");
}

export function notifyOrderChange(callback: () => void) {
  const eventSource = new EventSource("/api/order/notify");
  eventSource.onmessage = callback;
  return () => {
    eventSource.close();
  };
}
