import { OrderAction } from "@/hooks/useOrder";
import { cn } from "@/lib/utils";
import { Dispatch } from "react";
import { MenuItem } from "src/db";
import { Button } from "./ui/button";
import { Card, CardContent, CardHeader, CardTitle } from "./ui/card";
import { Tabs, TabsContent, TabsList, TabsTrigger } from "./ui/tabs";

export default function Menu({
  menus,
  categories,
  dispatch,
}: {
  menus: MenuItem[];
  categories: string[];
  dispatch: Dispatch<OrderAction>;
}) {
  const menu = menus;
  return (
    <Tabs defaultValue={categories[0]}>
      <TabsList>
        {[...categories].map(category => <TabsTrigger key={category} value={category}>{category}</TabsTrigger>)}
      </TabsList>
      {[...categories].map(category => (
        <TabsContent key={category} value={category}>
          <Card>
            <CardHeader>
              <CardTitle>{category}</CardTitle>
            </CardHeader>
            <CardContent>
              <ul className="w-full flex flex-col">
                {menu.filter(item => item.category === category).map((item, index) => (
                  <li
                    key={item.name}
                    className={cn(
                      "flex flex-col gap-2 sm:flex-wrap sm:justify-between sm:flex-row",
                      index % 2 === 0 ? "bg-accent" : "",
                    )}
                  >
                    <span className="">{item.name}</span>
                    <div className="flex gap-2 justify-between">
                      {item.price != null
                        ? (
                          <Button
                            variant="outline"
                            className=""
                            onClick={() => {
                              dispatch({
                                type: "ADD_ORDER",
                                order: {
                                  name: item.name,
                                  HOT: 0,
                                  price: item.price ?? 0,
                                  quantity: 1,
                                },
                              });
                            }}
                          >
                            {item.price * 1000}원 주문
                          </Button>
                        )
                        : (
                          <>
                            <Button
                              variant="outline"
                              className="bg-sky-400 hover:bg-sky-500"
                              disabled={!item.COLD}
                              onClick={() => {
                                dispatch({
                                  type: "ADD_ORDER",
                                  order: {
                                    name: item.name,
                                    HOT: 1,
                                    price: item.COLD ?? 0,
                                    quantity: 1,
                                  },
                                });
                              }}
                            >
                              {(item.COLD ?? 0) * 1000}원 ICE 주문
                            </Button>
                            <Button
                              variant="outline"
                              className="bg-red-400 hover:bg-red-500"
                              disabled={!item.HOT}
                              onClick={() => {
                                dispatch({
                                  type: "ADD_ORDER",
                                  order: {
                                    name: item.name,
                                    HOT: 1,
                                    price: item.HOT ?? 0,
                                    quantity: 1,
                                  },
                                });
                              }}
                            >
                              {(item.HOT ?? 0) * 1000} HOT 주문
                            </Button>
                          </>
                        )}
                    </div>
                  </li>
                ))}
              </ul>
            </CardContent>
          </Card>
        </TabsContent>
      ))}
    </Tabs>
  );
}
