import { Input } from "@/components/ui/input";
import { cn } from "@/lib/utils";
import { UpdateMenuItemType } from "src/schema";
import { onlyNumber } from "../../lib/onlyNumber.tsx";

export function MenuInput({
  data,
  onChange,
  className = "",
}: {
  data: UpdateMenuItemType;
  onChange: (data: UpdateMenuItemType) => void;
  className?: string;
}) {
  return (
    <div className={cn("grid gap-2", className)}>
      <div>
        <div className="text-muted-foreground">카테고리</div>
        <Input
          value={data.category}
          onChange={(e) =>
            onChange({
              ...data,
              category: e.target.value,
            })}
        />
      </div>
      <div>
        <div className="text-muted-foreground">Hot 가격</div>
        <Input
          value={data.HOT ? (data.HOT * 1000).toString() : ""}
          onChange={(e) =>
            onChange({
              ...data,
              HOT: e.target.value ? parseInt(onlyNumber(e.target.value)) / 1000 : null,
            })}
        />
      </div>
      <div>
        <div className="text-muted-foreground">Ice 가격</div>
        <Input
          value={data.COLD ? (data.COLD * 1000).toString() : ""}
          onChange={(e) =>
            onChange({
              ...data,
              COLD: e.target.value ? parseInt(onlyNumber(e.target.value)) / 1000 : null,
            })}
        />
      </div>
      <div>
        <div className="text-muted-foreground">그냥 가격</div>
        <Input
          value={data.price ? (data.price * 1000).toString() : ""}
          onChange={(e) =>
            onChange({
              ...data,
              price: e.target.value ? parseInt(onlyNumber(e.target.value)) / 1000 : null,
            })}
        />
      </div>
    </div>
  );
}
