import { Button } from "@/components/ui/button";
import {
  Drawer,
  DrawerContent,
  DrawerDescription,
  DrawerFooter,
  DrawerHeader,
  DrawerTitle,
  DrawerTrigger,
} from "@/components/ui/drawer";
import { useDeleteMenuItem, useUpdateMenuItem } from "@/hooks/useMenu";
import { TrashIcon } from "@radix-ui/react-icons";
import { useQueryClient } from "@tanstack/react-query";
import { useState } from "react";
import { MenuItemColumns } from "src/db";
import { UpdateMenuItemType } from "src/schema";
import { currencyFormat } from "../../lib/currencyFormat.tsx";
import { MenuInput } from "./MenuInput.tsx";

export function MenuItem({
  item,
}: {
  item: MenuItemColumns;
}) {
  const [drawerOpen, setDrawerOpen] = useState(false);
  const [deleteDrawerOpen, setDeleteDrawerOpen] = useState(false);
  const queryClient = useQueryClient();
  const { mutate: mutateUpdate, isPending: isUpdatePending } = useUpdateMenuItem(queryClient);
  const { mutate: mutateDelete, isPending: isDeletePending } = useDeleteMenuItem(queryClient);
  const [data, setData] = useState<UpdateMenuItemType>({
    category: item.category,
    HOT: item.HOT,
    COLD: item.COLD,
    price: item.price,
  });

  return (
    <>
      <Drawer open={deleteDrawerOpen} onOpenChange={setDeleteDrawerOpen}>
        <DrawerContent>
          <DrawerHeader>
            <DrawerTitle>{item.name} 삭제</DrawerTitle>
            <DrawerDescription>메뉴를 삭제합니다.</DrawerDescription>
          </DrawerHeader>
          <DrawerFooter>
            <Button
              variant="destructive"
              disabled={isDeletePending}
              onClick={() => {
                mutateDelete(item.name, {
                  onSuccess: () => {
                    setDeleteDrawerOpen(false);
                  },
                });
              }}
            >
              삭제하기
            </Button>
          </DrawerFooter>
        </DrawerContent>
      </Drawer>
      <Drawer open={drawerOpen} onOpenChange={setDrawerOpen}>
        <DrawerTrigger asChild>
          <div className="border p-4 hover:bg-accent relative">
            <Button
              variant="ghost"
              disabled={isDeletePending}
              className="absolute top-4 right-2"
              onClick={(e) => {
                setDeleteDrawerOpen(true);
                e.stopPropagation();
              }}
            >
              <TrashIcon />
            </Button>
            <span className="text-muted-foreground font-light text-sm leading-3">{item.category}</span>
            <h2 className="text-xl font-bold">{item.name}</h2>
            {item.HOT && <p className="text-sm text-muted-foreground">HOT {currencyFormat(item.HOT * 1000)}</p>}
            {item.COLD && <p className="text-sm text-muted-foreground">COLD {currencyFormat(item.COLD * 1000)}</p>}
            {item.price && <p className="text-sm text-muted-foreground">{currencyFormat(item.price * 1000)}</p>}
          </div>
        </DrawerTrigger>
        <DrawerContent>
          <DrawerHeader>
            <DrawerTitle>{item.name} 수정</DrawerTitle>
            <DrawerDescription>메뉴를 수정합니다.</DrawerDescription>
          </DrawerHeader>
          <MenuInput className="m-4" data={data} onChange={setData} />
          <DrawerFooter>
            <Button
              variant="default"
              disabled={isUpdatePending}
              onClick={() => {
                mutateUpdate({
                  ...item,
                  ...data,
                }, {
                  onSuccess: () => {
                    setDrawerOpen(false);
                  },
                });
              }}
            >
              수정하기
            </Button>
          </DrawerFooter>
        </DrawerContent>
      </Drawer>
    </>
  );
}
