import { useCancelOrder, useCompleteOrder } from "@/hooks/useOrders";
import { TrashIcon } from "@radix-ui/react-icons";
import { useQueryClient } from "@tanstack/react-query";
import { OrderStateColumns } from "src/db";
import { Button } from "./ui/button";
import { Card, CardContent, CardDescription, CardFooter, CardHeader, CardTitle } from "./ui/card";
import {
  Drawer,
  DrawerClose,
  DrawerContent,
  DrawerDescription,
  DrawerHeader,
  DrawerTitle,
  DrawerTrigger,
} from "./ui/drawer";

export default function OrderCard({
  order,
}: {
  order: OrderStateColumns;
}) {
  const queryClient = useQueryClient();
  const { mutate: mutateCompleteOrder, isPending: isCompleteOrderPending } = useCompleteOrder(queryClient);
  const { mutate: mutateCancelOrder, isPending: isCancelOrderPending } = useCancelOrder(queryClient);

  return (
    <Card className="flex flex-col h-60">
      <CardHeader className="relative">
        <div className="absolute right-2">
          <Drawer>
            <DrawerTrigger asChild>
              <Button variant="ghost" disabled={order.completed == 1 || isCancelOrderPending}>
                <TrashIcon />
              </Button>
            </DrawerTrigger>
            <DrawerContent>
              <DrawerHeader>
                <DrawerTitle>
                  주문 취소
                </DrawerTitle>
                <DrawerDescription>
                  정말로 주문을 취소하시겠습니까?
                </DrawerDescription>
              </DrawerHeader>
              <DrawerClose asChild>
                <Button
                  onClick={() => {
                    mutateCancelOrder(order.id);
                  }}
                >
                  취소
                </Button>
              </DrawerClose>
            </DrawerContent>
          </Drawer>
        </div>
        <CardTitle className={order.completed == 1 ? "text-muted-foreground" : ""}>
          {order.id.split("/")[1]}번 주문
        </CardTitle>
        <CardDescription>{order.completed ? "완료" : "대기중..."}</CardDescription>
      </CardHeader>
      <CardContent className="flex-1 overflow-auto">
        <hr />
        {order.orders.map((item) => (
          <div key={item.name}>
            <span>{item.HOT ? "HOT" : "COLD"} {item.name} {item.quantity}</span>
          </div>
        ))}
      </CardContent>
      <CardFooter>
        <Button
          disabled={isCompleteOrderPending}
          onClick={() => {
            mutateCompleteOrder({
              completed: order.completed ? 0 : 1,
              id: order.id,
            });
          }}
        >
          {order.completed == 0 ? "완료" : "완료 취소"}
        </Button>
      </CardFooter>
    </Card>
  );
}
