"use client";

import { useAddOrder } from "@/hooks/useOrders";
import { useQueryClient } from "@tanstack/react-query";
import { MenuItem } from "src/db";
import { useLocation } from "wouter";
import { useOrder } from "../hooks/useOrder";
import Menu from "./menu";
import { Button } from "./ui/button";
import {
  Drawer,
  DrawerClose,
  DrawerContent,
  DrawerFooter,
  DrawerHeader,
  DrawerTitle,
  DrawerTrigger,
} from "./ui/drawer";

export default function Order({
  menus,
  categories,
}: {
  menus: MenuItem[];
  categories: string[];
}) {
  const queryClient = useQueryClient();
  const { state, dispatch } = useOrder();
  const { mutate, isPending } = useAddOrder(queryClient);
  const [, navigate] = useLocation();

  return (
    <>
      <Menu menus={menus} categories={categories} dispatch={dispatch} />
      <Drawer>
        <DrawerTrigger asChild>
          <Button className="w-full mt-2 flex items-center">
            Order{" "}
            <span className="
            ml-1 flex items-center justify-center rounded-full h-6 px-1 text-center bg-background text-foreground">
              {state.orders.reduce(
                (acc, order) => acc + order.quantity,
                0,
              )}
            </span>
          </Button>
        </DrawerTrigger>
        <DrawerContent>
          <DrawerHeader>
            <DrawerTitle>다음 주문이 맞나요?</DrawerTitle>
          </DrawerHeader>
          <hr className="mx-4" />
          <ul className="flex flex-col gap-2 justify-center m-4">
            {state.orders.map(order => (
              <li key={`${order.HOT ? "HOT" : "COLD"} ${order.name}`} className="flex items-center justify-between">
                <div className="flex flex-wrap gap-2">
                  <div className="space-x-2 font-bold">
                    <span className="w-12">{order.HOT ? "HOT " : "COLD"}</span>
                    <span className="flex-1 break-words">{order.name}</span>
                  </div>
                  <div className="flex flex-wrap gap-x-2">
                    <div className="space-x-2">
                      <span className="flex-1 break-words">{order.price * 1000}원</span>
                      <span className="flex-1">{order.quantity}개</span>
                    </div>
                    <span className="flex-1 text-nowrap">총가격 {order.price * order.quantity * 1000}원</span>
                  </div>
                </div>
                <div className="space-x-2 flex">
                  <Button
                    variant="outline"
                    className="rounded-full"
                    onClick={() =>
                      dispatch({
                        type: "ADD_ORDER",
                        order: {
                          ...order,
                          quantity: 1,
                        },
                      })}
                  >
                    +1
                  </Button>
                  <Button
                    variant="outline"
                    className="rounded-full"
                    onClick={() =>
                      dispatch({
                        type: "ADD_ORDER",
                        order: {
                          ...order,
                          quantity: -1,
                        },
                      })}
                  >
                    -1
                  </Button>
                  <Button
                    variant="outline"
                    onClick={() =>
                      dispatch({ type: "REMOVE_ORDER", order })}
                  >
                    취소
                  </Button>
                </div>
              </li>
            ))}
          </ul>
          <hr className="mx-4" />
          <div className="flex mx-4 flex-col items-end">
            <span className="text-sm text-muted-foreground">총 가격</span>
            <span className="flex-1 text-lg">
              {state.orders.map(order => order.price * order.quantity)
                .reduce((acc, price) => acc + price, 0) * 1000}원
            </span>
          </div>
          <DrawerFooter>
            <DrawerClose asChild>
              <Button
                disabled={isPending}
                onClick={async () => {
                  console.log("menu order start");
                  mutate({
                    orders: state.orders,
                    payment: "account",
                  }, {
                    onSuccess: () => {
                      navigate("/");
                    },
                  });
                }}
              >
                계좌이체 주문하기
              </Button>
            </DrawerClose>
            <DrawerClose asChild>
              <Button
                disabled={isPending}
                onClick={async () => {
                  console.log("cash order start");
                  mutate({
                    orders: state.orders,
                    payment: "cash",
                  }, {
                    onSuccess: () => {
                      navigate("/");
                    },
                  });
                }}
              >
                현금 주문하기
              </Button>
            </DrawerClose>
          </DrawerFooter>
        </DrawerContent>
      </Drawer>
    </>
  );
}
