import { addNewMenuItem, deleteMenuItem, getListMenuItems, updateMenuItem } from "@/api/menu";
import { QueryClient, useMutation, useQuery } from "@tanstack/react-query";
import { AddNewMenuItemType } from "src/schema";

export function useMenu() {
  return useQuery({
    queryKey: ["menu"],
    queryFn: getListMenuItems,
  });
}

export function useAddMenuItem(queryClient: QueryClient) {
  return useMutation({
    mutationKey: ["menu"],
    mutationFn: ({
      name,
      ...rest
    }: {
      name: string;
    } & AddNewMenuItemType) => addNewMenuItem(name, rest),
    onSuccess: (_data, _variables, _context) => {
      queryClient.invalidateQueries({
        queryKey: ["menu"],
      });
    },
  }, queryClient);
}

export function useUpdateMenuItem(queryClient: QueryClient) {
  return useMutation({
    mutationKey: ["menu"],
    mutationFn: ({
      name,
      ...rest
    }: {
      name: string;
    } & AddNewMenuItemType) => updateMenuItem(name, rest),
    onSuccess: (_data, _variables, _context) => {
      queryClient.invalidateQueries({
        queryKey: ["menu"],
      });
    },
  }, queryClient);
}

export function useDeleteMenuItem(queryClient: QueryClient) {
  return useMutation({
    mutationKey: ["menu"],
    mutationFn: deleteMenuItem,
    onSuccess: (_data, _variables, _context) => {
      queryClient.invalidateQueries({
        queryKey: ["menu"],
      });
    },
  }, queryClient);
}
