import { QueryClient, useMutation, useQuery } from "@tanstack/react-query";
import { useEffect } from "react";
import {
  addNewOrder,
  cancelCompleteOrder,
  cancelOrder,
  completeOrder,
  loadOrder,
  notifyOrderChange,
} from "../api/order";

export function useOrders() {
  return useQuery({
    queryKey: ["orders"],
    queryFn: loadOrder,
  });
}

export function useAddOrder(queryClient: QueryClient) {
  return useMutation({
    mutationKey: ["orders"],
    mutationFn: addNewOrder,
    onSuccess: (_data, _variables, _context) => {
      queryClient.invalidateQueries({
        queryKey: ["orders"],
      });
    },
  }, queryClient);
}

export function useCancelOrder(queryClient: QueryClient) {
  return useMutation({
    mutationKey: ["orders"],
    mutationFn: cancelOrder,
    onSuccess: (_data, _variables, _context) => {
      queryClient.invalidateQueries({
        queryKey: ["orders"],
      });
    },
  }, queryClient);
}

export function useCompleteOrder(queryClient: QueryClient) {
  return useMutation({
    mutationKey: ["orders"],
    mutationFn: ({
      id,
      completed,
    }: {
      id: string;
      completed: 0 | 1;
    }) => completed ? completeOrder(id) : cancelCompleteOrder(id),
    onSuccess: (_data, _variables, _context) => {
      queryClient.invalidateQueries({
        queryKey: ["orders"],
      });
    },
  }, queryClient);
}

export function useNotifyOrderChange(callback: () => void) {
  useEffect(() => {
    return notifyOrderChange(callback);
  }, [callback]);
}

export function useOrderAutoRefresh(queryClient: QueryClient) {
  useNotifyOrderChange(() => {
    queryClient.invalidateQueries({
      queryKey: ["orders"],
    });
  });
}
