import { Insertable, JSONColumnType, Selectable, Updateable } from "kysely";

export type MenuItem = {
  name: string;
  HOT: number | null;
  COLD: number | null;
  price: number | null;
  category: string;
};

export type NewMenuItem = Insertable<MenuItem>;
export type MenuItemColumns = Selectable<MenuItem>;
export type MenuItemUpdate = Updateable<MenuItem>;

export interface Order {
  name: string;
  quantity: number;
  price: number;
  // SQLite has no Boolean datatype. Use cast(1|0|SqliteBoolean).
  HOT: 0 | 1;
}

export type PaymentMethod = "account" | "cash";

export interface OrderState {
  id: string;
  orders: JSONColumnType<Order[]>;
  completed: 0 | 1;
  payment: PaymentMethod;
}

export type NewOrderState = Insertable<OrderState>;
export type OrderStateColumns = Selectable<OrderState>;
export type OrderStateUpdate = Updateable<OrderState>;

export interface OrderNumber {
  id: string;
  number: number;
}

export type NewOrderNumber = Insertable<OrderNumber>;
export type OrderNumberColumns = Selectable<OrderNumber>;
export type OrderNumberUpdate = Updateable<OrderNumber>;

export interface Database {
  Order_State: OrderState;
  Order_Number: OrderNumber;
  Menu: MenuItem;
}
