import { NextFunction, Request, Response } from "express";
import { ZodError } from "zod";

export function errorWrapper(fn: (req: Request, res: Response, next: NextFunction) => Promise<void>) {
  return async (req: Request, res: Response, next: NextFunction) => {
    try {
      await fn(req, res, next);
    } catch (e) {
      errorHandler(e, req, res, next);
    }
  };
}

export function errorHandler(err: unknown, req: Request, res: Response, _next: NextFunction) {
  if (err instanceof ZodError) {
    res.status(400).json({
      error: err.errors,
      errorType: "ZodError",
      message: `Invalid request body: ${err.message}`,
    });
    return;
  }
  if (err instanceof Error) {
    console.error(err);
    res.status(500).json({ error: err.message });
  } else {
    // This should never happen. If it does, it's a bug in the server code.
    // error must be an instance of Error.
    console.error(err);
    res.status(500).json({ error: "An unknown error occurred" });
  }
}
