import { Router } from "express";
import { updateMenuItemSchema } from "src/schema.ts";
import { addNewMenuItemSchema } from "../schema.ts";
import { addNewMenuItem, deleteMenuItem, listMenuItems, updateMenuItem } from "./db.ts";
import { errorWrapper } from "./error_handler.ts";

const router = Router();

router.get(
  "/menu",
  errorWrapper(async (req, res) => {
    res.json(await listMenuItems());
  }),
);

router.post(
  "/menu/:name",
  errorWrapper(async (req, res, _) => {
    const name = req.params.name;
    const item = addNewMenuItemSchema.parse(req.body);
    await addNewMenuItem({ ...item, name });
    res.json({ success: true });
  }),
);

router.patch(
  "/menu/:name",
  errorWrapper(async (req, res) => {
    const name = req.params.name;
    const item = updateMenuItemSchema.parse(req.body);
    await updateMenuItem(name, item);
    res.json({ success: true });
  }),
);

router.delete(
  "/menu/:name",
  errorWrapper(async (req, res) => {
    await deleteMenuItem(req.params.name);
    res.json({ success: true });
  }),
);

export default router;
